Learn R Programming

medicalcoder (version 0.8.0)

get_charlson_index_scores: Get Charlson Index Scores

Description

Retrieve a copy of internal lookup tables of index scores used in assessing Charlson comorbidities.

Usage

get_charlson_index_scores()

Arguments

Value

A data.frame with the following columns:

  • condition: Character vector of the conditions

  • index: Character vector indicating if the score is for the mortality or the readmission index score

  • charlson_<variant>: the index scores for the variant

See Also

  • get_charlson_codes() for a lookup table of the ICD codes mapping to the Charlson comorbidities.

  • comorbidities() for applying comorbidity algorithms to a data set.

Examples

Run this code
head(get_charlson_index_scores())
str(get_charlson_index_scores())

Run the code above in your browser using DataLab