powered by
Retrieve a copy of internal lookup tables of index scores used in assessing Charlson comorbidities.
get_charlson_index_scores()
A data.frame with the following columns:
data.frame
condition: Character vector of the conditions
condition
index: Character vector indicating if the score is for the mortality or the readmission index score
index
charlson_<variant>: the index scores for the variant
charlson_<variant>
get_charlson_codes() for a lookup table of the ICD codes mapping to the Charlson comorbidities.
get_charlson_codes()
comorbidities() for applying comorbidity algorithms to a data set.
comorbidities()
head(get_charlson_index_scores()) str(get_charlson_index_scores())
Run the code above in your browser using DataLab