Learn R Programming

medicalcoder (version 0.7.0)

summary.medicalcoder_comorbidities_with_subconditions: Summaries of Comorbidities with Subconditions

Description

Build summaries (counts and percentages) for each Pediatric Complex Chronic Condition (PCCC) condition and subcondition.

Usage

# S3 method for medicalcoder_comorbidities_with_subconditions
summary(object, ...)

Value

a data.frame with five columns.

  1. condition the primary condition

  2. subcondition the subcondition(s) within the condition. There will be a row where subcondition is NA which is used to report the count and percent_of_cohort for the condition overall.

  3. count the number of rows in object with the applicable condition and subcondition.

  4. percent_of_cohort: a numeric value within [0, 100] for the percent of rows in object with the flagged condition and subcondition.

  5. percent_of_those_with_condition: a numeric value within [0, 100] for the subset of rows in object with the primary condition and the flagged subcondition. Will be NA for the primary condition.

Arguments

object

a medicalcoder_comorbidities_with_subcondtions object generated by calling comorbidities() with subconditions = TRUE. This is currently only applicable to PCCC.

...

additional parameters, not currently used

See Also

Examples

Run this code
pccc_v3.1_subcondition_results <-
  comorbidities(data = mdcr,
                icd.codes = "code",
                id.vars = "patid",
                dx.var = "dx",
                method = "pccc_v3.1",
                flag.method = 'current',
                poa = 1,
                subconditions = TRUE)
summary(pccc_v3.1_subcondition_results)

Run the code above in your browser using DataLab